@@ -10,7 +10,7 @@
 # sorry this code is so messy....its just hacked up....
 
 appname = "ankimaemi"
-appversion = "0.0.6"
+appversion = "0.0.7"
 
 import os
 os.environ["SDL_VIDEO_X11_WMCLASS"]=appname
@@ -28,7 +28,7 @@ from anki.sync import SyncClient, HttpSyncServerProxy
 from anki.media import mediaRefs
 from anki.utils import parseTags, joinTags
 
-from gnome import gconf 
+from gnome import gconf
 
 def request_object(*args):
     print 'request object', args
@@ -50,6 +50,9 @@ class AnkiMiniApp(hildon.Program):
     recent_decks = []
     recent_sub_menu = None
 
+    card_font_size = 30
+    redraw_func = None
+
     def __init__(self):
         hildon.Program.__init__(self)
 
@@ -64,10 +67,10 @@ class AnkiMiniApp(hildon.Program):
         self.add_window(self.window)
         self.mainbox = gtk.VBox(False, 0)
         self.window.add(self.mainbox)
-        
+
         self.statsbox = gtk.HBox(False, 0)
         self.mainbox.pack_start(self.statsbox, False, True, 0)
-        
+
         self.statslabel = gtk.Label()
         self.statslabel.set_markup("T: 0/0 (0.0%) A: <b>0.0%</b>. ETA: <b>Unknown</b>")
         self.statsbox.pack_start(self.statslabel, True, True, 0)
@@ -77,13 +80,13 @@ class AnkiMiniApp(hildon.Program):
         self.missinglabel.set_markup('<span foreground="red">0</span>+0+<span foreground="blue">0</span>')
         self.statsbox.pack_end(self.missinglabel, True, True, 0)
         self.missinglabel.show()
-        
+
         self.statsbox.show()
-        
+
         self.opbuttonsbox = gtk.HBox(False, 30)
         self.opbuttonsbox.set_size_request(400, 35)
         self.mainbox.pack_start(self.opbuttonsbox, False, False, 0)
-        
+
         self.savebutton = gtk.Button()
         self.savebutton.connect("clicked", self.opbutclick, "save")
         self.savebuttonlabel = gtk.Label("save")
@@ -104,23 +107,23 @@ class AnkiMiniApp(hildon.Program):
 
         self.opbuttonsbox.pack_start(self.markbutton, True, True, 0)
         self.markbutton.show()
-        
+
         self.replaybutton = gtk.Button("replay")
         self.replaybutton.connect("clicked", self.opbutclick, "replay")
         self.opbuttonsbox.pack_start(self.replaybutton, True, True, 0)
         self.replaybutton.show()
-        
+
         self.syncbutton = gtk.Button("sync")
         self.syncbutton.connect("clicked", self.opbutclick, "sync")
         self.opbuttonsbox.pack_start(self.syncbutton, True, True, 0)
         self.syncbutton.show()
-        
+
         self.opbuttonsbox.show()
-        
+
         self.qabox = gtk.VBox(False, 0)
         self.qabox.set_size_request(800, 250)
         self.mainbox.pack_start(self.qabox, True, True, 0)
-        
+
         self.document = gtkhtml2.Document()
 #    self.document.connect('request_url', request_url)
 #    self.document.connect('link_clicked', link_clicked)
@@ -130,18 +133,18 @@ class AnkiMiniApp(hildon.Program):
                           (appname, appversion))
         self.view.connect('request_object', request_object)
         self.qabox.pack_start(self.view, True, True, 0)
-        
+
         self.qabox.show()
-        
+
         self.answerbuttonbox = gtk.HBox(False, 0)
         self.answerbuttonbox.set_size_request(800, 80)
         self.mainbox.pack_end(self.answerbuttonbox, False, True, 0)
-        
+
         self.answerbutton = gtk.Button("Answer")
         self.answerbutton.connect("clicked", self.opbutclick, "answer")
         self.answerbuttonbox.pack_start(self.answerbutton, True, True, 0)
         self.answerbutton.show()
-        
+
         self.answerbuttonbox.show()
 
         self.learnmorebox = gtk.HBox(False, 0)
@@ -157,11 +160,11 @@ class AnkiMiniApp(hildon.Program):
         self.reviewearlybutton.connect("clicked", self.opbutclick, "reviewearly")
         self.learnmorebox.pack_start(self.reviewearlybutton, True, True, 0)
         self.reviewearlybutton.show()
-        
+
         self.resultbuttonbox = gtk.HBox(False, 15)
         self.resultbuttonbox.set_size_request(800, 80)
         self.mainbox.pack_end(self.resultbuttonbox, False, True, 0)
-        
+
         self.resbuttons = []
         for i in range(4):
             if i <> 0:
@@ -174,7 +177,7 @@ class AnkiMiniApp(hildon.Program):
             self.resbuttons.append(but)
 
         self.resultbuttonbox.show()
-    
+
         self.mainbox.show()
 
         self.menu = gtk.Menu()
@@ -215,7 +218,7 @@ class AnkiMiniApp(hildon.Program):
         self.menu.append(menuItemSeparator1)
         self.menu.append(menuItemExit)
         self.window.set_menu(self.menu)
-    
+
     def set_window_empty(self):
         self.opbuttonsbox.hide()
         self.answerbuttonbox.hide()
@@ -248,7 +251,7 @@ class AnkiMiniApp(hildon.Program):
 
 #        for f in range(5):
 #            self.recent_decks[f].get_children()[0].set_markup(self.recent_decks_files[f])
-       
+
     def init_deck(self):
         print "open deck.. " + self.DECK_PATH
         if not os.path.exists(self.DECK_PATH):
@@ -274,7 +277,7 @@ class AnkiMiniApp(hildon.Program):
     def choose_deck(self, widget, event):
         if self.deck:
             if self.deck.modifiedSinceSave() and self.yesno_dlg(gtk.MESSAGE_QUESTION, "Save the current deck first?"):
-                self.deck_save()                
+                self.deck_save()
 
         selector=hildon.FileChooserDialog(self.window,gtk.FILE_CHOOSER_ACTION_OPEN)
         rep=selector.run()
@@ -308,7 +311,7 @@ class AnkiMiniApp(hildon.Program):
                 self.set_question()
                 self.set_stats()
         gtk.main()
-    
+
     def set_stats(self):
         s = self.deck.getStats()
         stats = (("T: %(dYesTotal)d/%(dTotal)d "
@@ -326,7 +329,7 @@ class AnkiMiniApp(hildon.Program):
             else:
                 n = "<u>" + n + "</u>"
 
-        stats2 = ('%s+%s+%s' % (f,r,n)) % s                
+        stats2 = ('%s+%s+%s' % (f,r,n)) % s
         self.statslabel.set_markup(stats)
         self.missinglabel.set_markup(stats2)
 
@@ -343,6 +346,17 @@ class AnkiMiniApp(hildon.Program):
                 self.window.unfullscreen ()
             else:
                 self.window.fullscreen ()
+	# zoom in
+	elif event.keyval == gtk.keysyms.F7:
+		self.card_font_size += 3
+		if self.redraw_func:
+			self.redraw_func()
+	elif event.keyval == gtk.keysyms.F8:
+		self.card_font_size -= 3
+		if self.redraw_func:
+			self.redraw_func()
+		
+
 
     def set_html_doc(self, html_str):
         self.document.clear()
@@ -354,15 +368,15 @@ class AnkiMiniApp(hildon.Program):
     maximum-scale=0.6667" />
 <style>
 .q
-{ font-size: 30px; color:#0000ff;}
+{ font-family: "Deja-Vu Sans", sans-serif; font-size: %dpx; color:#0000ff;}
 .a
-{ font-size: 30px; }
+{ font-family: "Deja-Vu Sans", sans-serif; font-size: %dpx; }
 body { margin-top: 0px; padding: 0px; }
 </style>
 </head><body>
 %s
 </body></html>
-""" % html_str.replace('font-weight:600','font-weight:bold'))
+""" % (self.card_font_size, self.card_font_size, html_str.replace('font-weight:600','font-weight:bold')))
         self.document.close_stream()
         self.view.set_document(self.document)
 
@@ -404,6 +418,7 @@ body { margin-top: 0px; padding: 0px; }
             self.markbuttonlabel.set_markup('<span color="red">mark</span>')
         else:
             self.markbuttonlabel.set_markup('mark')
+	self.redraw_func = self.set_question
 
     def set_q_a(self):
         if not self.currentCard:
@@ -419,6 +434,7 @@ body { margin-top: 0px; padding: 0px; }
                           (self.prepareMedia(c.question, auto=False).encode("utf-8"), self.prepareMedia(c.answer).encode("utf-8")))
         for i in range(2, 5):
             self.resbuttons[i-1].set_label(self.deck.nextIntervalStr(c, i, True))
+	self.redraw_func = self.set_q_a
 
     def answer(self, q):
         if self.currentCard:
@@ -525,17 +541,17 @@ Fetching summary from server..<br>
             self.set_stats()
             self.conf_client.set_string("/apps/anki/general/deck_path", self.DECK_PATH)
         else:
-            self.DECK_PATH = ""   
+            self.DECK_PATH = ""
 
     def recentclick(self, widget, cmd):
         if self.deck and self.deck.modifiedSinceSave() and self.yesno_dlg(gtk.MESSAGE_QUESTION, "Save the current deck first?"):
-            self.deck_save()                
+            self.deck_save()
 
         self.replace_deck_with_file(cmd)
-        
+
 #        self.err_dlg("Open recent: %s" % cmd)
 
-        
+
     def opbutclick(self, widget, cmd):
         if cmd == 'save':
             if self.deck:
@@ -546,12 +562,13 @@ Fetching summary from server..<br>
             self.set_q_a()
             self.set_stats()
         elif cmd == 'close':
+            self.redraw_func = None
             if not self.deck:
                 return
-            
+
             if self.deck.modifiedSinceSave() and \
                     self.yesno_dlg(gtk.MESSAGE_QUESTION, "Save the current deck first?"):
-                self.deck_save()                
+                self.deck_save()
             self.deck.close()
             self.deck = None
             self.update_recent_menu(self.DECK_PATH)
@@ -610,7 +627,7 @@ Fetching summary from server..<br>
             self.set_stats()
 
 
-                              
+
     def resclick(self, widget, number):
         self.answer(number)
         self.set_question()
@@ -629,12 +646,12 @@ Fetching summary from server..<br>
         self.deck = None
 
         gtk.main_quit()
-        
+
     # Commit changes to the GConf database. 
     def config_entry_commit (self, entry, *args):
         client = entry.get_data ('client')
         text = entry.get_chars (0, -1)
-        
+
         key = entry.get_data ('key')
 
     # Unset if the string is zero-length, otherwise set
@@ -669,7 +686,7 @@ Fetching summary from server..<br>
 
         entry.connect ('focus_out_event', self.config_entry_commit)
         entry.connect ('activate', self.config_entry_commit)    
-   
+
         # Set the entry insensitive if the key it edits isn't writable.
         # Technically, we should update this sensitivity if the key gets
         # a change notify, but that's probably overkill.
@@ -678,7 +695,7 @@ Fetching summary from server..<br>
 
         if focus:
             entry.grab_focus ()
-  
+
         return hbox
 
     def run_settings(self, widget, event):
@@ -694,7 +711,7 @@ Fetching summary from server..<br>
 
         vbox = gtk.VBox (False, 5)
         vbox.set_border_width (5)
-        
+
         dialog.vbox.pack_start (vbox)
 
         entry = self.create_config_entry (dialog, self.conf_client, "Username:", "/apps/anki/general/sync_username", True)
@@ -705,7 +722,7 @@ Fetching summary from server..<br>
 
         dialog.show_all()
         dialog.run()
-        
+
         self.SYNC_USERNAME = self.conf_client.get_string("/apps/anki/general/sync_username")
         self.SYNC_PASSWORD = self.conf_client.get_string("/apps/anki/general/sync_password")
 
